/******************************************************************************\
* $Id: alert_summary_template.sas,v 1.1.2.7.4.1 2012/03/07 13:36:09 saswai Exp $
*
* Copyright(c) 2011 SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* Name: alert_summary_template.sas
*
* Purpose: Create the Alert_Summary table template
*
* Author: stuhor
*
* Support: SAS(r) Solutions OnDemand
*
* Input: libref.table_name	
*
* Output:	libref.table_name.sas7bdat 
*
* Parameters: table_in = libref.table_name
*
* Dependencies/Assumptions: 
*
* Usage:
*
* History: 
* ddmmmyyyy userid description (Change Code)
\******************************************************************************/


%macro alert_summary_template(table_in=);

%if &FCM_DEBUG > 1 %then %put NOTE:(FCM) Entering &SYSMACRONAME;

proc sql noprint;
	CREATE TABLE &table_in(
		/* These variables should always be present on the Alert_Summary table */
		ALERT_SK					NUMERIC(19),
		SEGMENT_ID					VARCHAR(128),
		SCENARIO_SK					NUMERIC(10),
		SCENARIO_DESC				VARCHAR(100),
		PROJECT_SK					NUMERIC(10),
		ENTITY_SK					NUMERIC(10),
		ENTITY_NM					VARCHAR(255),
		ENTITY_VARIABLE_SK			NUMERIC(10),
		RECIPIENT_TYPE_CD			VARCHAR(20),
		RECIPIENT_ID				VARCHAR(32),
		ALERT_STATUS_CD				VARCHAR(20),
		SCENARIO_SEVERITY_SCORE_NO	NUMERIC(10,2),
		SCENARIO_WEIGHT_NO			NUMERIC(10,2),
		OPEN_FLG					CHAR(1),
		ALERT_SUPPRESSED_FLG		CHAR(1),
		SUPPRESSION_END_DT			DATE FORMAT=DATETIME20.,
		ALERT_TRIGGER_TXT			VARCHAR(512),
		RECORD_VERSION_NO			NUMERIC(10),
		RUN_DT						DATE FORMAT=DATETIME20.,

		/* These variables should be present unless you have written a custom scoring scenario and customized the FCM.FCM_Alert_Entity table */
		SCENARIO_LOSS_AMT			NUMERIC(15,3),
		N_ALERTS_SCORE_NO			NUMERIC(10),
		AMT_LOSS_SCORE_NO			NUMERIC(10),
		SEVERITY_SCORE_NO			NUMERIC(10),
		ACTIONABLE_ENTITY_SCORE_NO	NUMERIC(10),
		ACTIONABLE_ENTITY_RANK_NO	NUMERIC(10),
		TOTAL_N_ALERTS_NO			NUMERIC(10),
		OVERALL_ACTIONABLE_ENTITY_RANK NUMERIC(10),

		/* These are optional enrichment fields that will depend on what enrichment data you require */
		SCENARIO_NM					VARCHAR(255),
		ALERT_TYPE					VARCHAR(20),
		FACILITY_NM					VARCHAR(60),
		FIRST_NM					VARCHAR(60),
		MIDDLE_NM					VARCHAR(60),
		LAST_NM						VARCHAR(60),
		ADDRESS_LINE_1_TXT			VARCHAR(100),
		ADDRESS_LINE_2_TXT			VARCHAR(100),
		CITY_NM						VARCHAR(100),
		POSTAL_CD					VARCHAR(20),
		WORK_PHONE_NO				VARCHAR(20),
		HOME_PHONE_NO				VARCHAR(20),
		GENDER_CD					VARCHAR(3),
		BIRTH_DT					DATE FORMAT=DATETIME20.,
		PROVIDER_SPECIALTY_DESC		VARCHAR(100),
		CLAIM_ID					VARCHAR(32),
		XCLM_BILL_AMT				NUMERIC(15,3),
		TOTAL_PAID_AMT				NUMERIC(15,3),
		SUBMITTED_DT				DATE FORMAT=DATETIME20.,
		CREATED_USER_ID				VARCHAR(32),
		CREATED_MS_NO				NUMERIC(19),
		MODIFIED_USER_ID			VARCHAR(32),
		MODIFIED_MS_NO				NUMERIC(19),
		VALID_FROM_DTTM				DATE FORMAT=DATETIME20.,
		VALID_TO_DTTM				DATE FORMAT=DATETIME20.,
		PROCESSED_DTTM				DATE FORMAT=DATETIME20.
	)
	;
quit;

%if &FCM_DEBUG > 1 %then %put NOTE:(FCM) Exiting &SYSMACRONAME;
%mend alert_summary_template;
	                                                                                                                                                                                                            
/*%alert_summary_template(table_in=fcm_prep.alert_summary)*/
