/******************************************************************************\
* $Id: proj_parameter_view.sas,v 1.1.2.1.4.1 2012/03/07 13:36:12 saswai Exp $ 
*
* Copyright(c) 2011 SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* Name: proj_parameter_view.sas
*
* Purpose: Creates table proj_parameter_view.  Values from this table populate the
*		   macro parameters that are 'wrapped' around provided scenario logic 
* 
*
* Author: jischn,jabloo
*
* Support: SAS(r) Solutions OnDemand
*
* Input: WORK._SCENARIO_VIEW
*		 (FCM).FCM_PARAMETER 
* Output:	
*			
* Parameters: (if applicable)
*
* Dependencies/Assumptions: 	_SCENARIO_VIEW as SCENARIO
*								FCM.FCM_PARAMETER 
* Usage:  
*
* History: 
* ddmmmyyyy userid description (Change Code)
* 
* 02AUG2011 jfraley Initial check in
* 16AUG2011 jabloo  Add header, edit SELECT scenario* to scenario.project_rk 
*                   and edit select for union to avoid collision
* 09SEP2011 jabloo  change to create a table, not a view since I have to SORT
* 18Jan2012 saswai	Added data step to wrap comma-separated lists in %quotes
\******************************************************************************/



proc sql noprint;
	create table PROJ_PARAMETER_VIEW as
	select PROJECT_RK, SCENARIO_RK, PARAMETER_NM, PARAMETER_VALUE
	from
	(
	  select scenario.PROJECT_RK, 
			sp.PARENT_RK as SCENARIO_RK, 
            sp.PARAMETER_NM as PARAMETER_NM,
            sp.PARAMETER_VALUE as PARAMETER_VALUE

      from _SCENARIO_VIEW as SCENARIO,
      		&libref..FCM_PARAMETER as SP 

      where scenario.LOGICAL_RK=sp.PARENT_RK 
            and scenario.LOGICAL_DELETE_FLG = "N"
            and sp.LOGICAL_DELETE_FLG = "N"
            and sp.PROJECT_PARAMETER_RK is null

      union

     select scenario.PROJECT_RK,
            sp.PARENT_RK as SCENARIO_RK, 
            sp.PARAMETER_NM as PARAMETER_NM,
            pp.PARAMETER_VALUE as PARAMETER_VALUE

      from  _scenario_view as SCENARIO,
            &libref..FCM_PARAMETER as sp,
            &libref..FCM_PARAMETER as pp

      where scenario.LOGICAL_RK=sp.PARENT_RK 
			and sp.PROJECT_PARAMETER_RK=pp.LOGICAL_RK 
			and scenario.LOGICAL_DELETE_FLG='N'
			and sp.LOGICAL_DELETE_FLG = "N"
			and pp.LOGICAL_DELETE_FLG = "N"
	)      
;
quit; 

/* Sort is needed because we found an ORDER BY would not order across   */
/* the UNION when we were trying to create a VIEW.  Now create a table, */
/* and just SORT it.                                                    */

proc sort data=PROJ_PARAMETER_VIEW out=PROJ_PARAMETER_VIEW;
	by project_rk scenario_rk;
run;

/* Wrap any parameter values in the %quote() function if the paramater values contains commas 
   which indicates a list */
data PROJ_PARAMETER_VIEW; 
	set PROJ_PARAMETER_VIEW;
	if ( index(parameter_value, ',') > 0 ) then
		parameter_value = compbl('%quote(' || parameter_value || ')');
run;
