/******************************************************************************\
* $Id: recipient_view.sas,v 1.1.2.1.4.1 2012/03/07 13:36:13 saswai Exp $
*
* Copyright(c) 2011 SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* Name: recipient_view.sas
*
* Purpose: Creates a table for the purpose of deciding the proper recipient_type_cd
* and recipient_id for each scenario
*
* Author: stuhor
*
* Support: SAS(r) Solutions OnDemand
*
* Input: 	
*
* Output:	recipient_view.sas7bdat
*			
* Parameters: (if applicable)
*
* Dependencies/Assumptions: 	FCM.FCM_PROJECT,
*								FCM.FCM_SCENARIO_GROUP,
*								FCM.FCM_SCENARIO
* Usage:
*
* ddmmmyyyy userid description (Change Code)
* History: Initial check in
\******************************************************************************/

proc sql;
	create table _RECIPIENT_VIEW as
	SELECT 	p.LOGICAL_RK label='PROJECT_RK' as PROJECT_RK,
			p.RECIPIENT_TYPE_CD label='P_RECIPIENT_TYPE_CD' as P_RECIPIENT_TYPE_CD,
			p.RECIPIENT_ID label='P_RECIPIENT_ID' as P_RECIPIENT_ID, 

			sg.LOGICAL_RK label='SCENARIO_GROUP_RK' as SCENARIO_GROUP_RK,
			sg.RECIPIENT_TYPE_CD label='SG_RECIPIENT_TYPE_CD' as SG_RECIPIENT_TYPE_CD,
			sg.RECIPIENT_ID label='SG_RECIPIENT_TYPE_CD' as SG_RECIPIENT_ID,

			s.LOGICAL_RK label='SCENARIO_RK' as SCENARIO_RK,
			s.RECIPIENT_TYPE_CD label='S_RECIPIENT_TYPE_CD' as S_RECIPIENT_TYPE_CD,
			s.RECIPIENT_ID label='S_RECIPIENT_ID' as S_RECIPIENT_ID  
	FROM &libref..FCM_PROJECT as p 
	LEFT JOIN
		&libref..FCM_SCENARIO_GROUP as sg
		ON p.LOGICAL_RK = sg.PROJECT_RK AND
			sg.LOGICAL_DELETE_FLG = 'N'
	LEFT JOIN 
		&libref..FCM_SCENARIO as s 
		ON sg.LOGICAL_RK = s.SCENARIO_GROUP_RK	AND
			s.LOGICAL_DELETE_FLG = 'N'
	WHERE p.RECIPIENT_ID IS NOT NULL 
		 AND p.RECIPIENT_TYPE_CD IS NOT NULL 
		 AND p.LOGICAL_DELETE_FLG = 'N';
quit;

data recipient_view;
	set _recipient_view;
	if s_recipient_type_cd = '' then do;
		if sg_recipient_type_cd = '' then
			s_recipient_type_cd = p_recipient_type_cd;
		else s_recipient_type_cd = sg_recipient_type_cd;
	end;
	if s_recipient_id = '' then do;
		if sg_recipient_id = '' then
			s_recipient_id = p_recipient_id;
		else s_recipient_id = sg_recipient_id;
	end;
run;
